@@ -88,6 +88,7 @@ MagRectangle target_rect;
 static MagRectangle rect;
 
 static MagRectangle roi_viewport;
+extern MagRectangle zp_rect;
 
 /*__DEBUG FUNCION*/
 void 
@@ -584,6 +585,8 @@ mag_zoomer_set_ZP_extents_left (MagZoomer *mag_zoomer,
 
     zp_left = atoi (ZPLeft);
     
+    zp_rect.left = zp_left;    
+    
     zoom_factor_changed = TRUE;
     
     if ( zp_left > target_rect.left)
@@ -593,7 +596,7 @@ mag_zoomer_set_ZP_extents_left (MagZoomer *mag_zoomer,
 
     magnifier_set_target (magnifier,
 			 &((mag_zoomer->zoomer_placement).extents));
-
+			 
     temp_rect.left = temp_rect.top = 0;
     temp_rect.width = mag_zoomer->zoomer_placement.extents.width - mag_zoomer->zoomer_placement.extents.left;
     temp_rect.height = mag_zoomer->zoomer_placement.extents.height - mag_zoomer->zoomer_placement.extents.top;
@@ -614,6 +617,8 @@ void mag_zoomer_set_ZP_extents_top (MagZoomer *mag_zoomer,
 
     zp_top = atoi (ZPTop);
     
+    zp_rect.top = zp_top;
+    
     zoom_factor_changed = TRUE;
 
     if ( zp_top > target_rect.top)
@@ -645,6 +650,8 @@ mag_zoomer_set_ZP_extents_width (MagZoomer *mag_zoomer,
 	
     zp_width = atoi (ZPWidth);
     
+    zp_rect.width = zp_width;
+
     zoom_factor_changed = TRUE;
 
     if ( zp_width < target_rect.width)
@@ -675,9 +682,11 @@ mag_zoomer_set_ZP_extents_height (MagZoomer *mag_zoomer,
 	return;
 
     zp_height = atoi (ZPHeight);
-
+    
+    zp_rect.height = zp_height;
+    
     zoom_factor_changed = TRUE;
-	
+    	
     if ( zp_height < target_rect.height)
         mag_zoomer->zoomer_placement.extents.height = zp_height;
     else
@@ -715,7 +724,7 @@ mag_zoomers_init ()
 {
 	mag_zoomers_hash_table = g_hash_table_new (g_str_hash, g_str_equal);
 	
-
+	
 }
 
 void 
@@ -1468,7 +1477,7 @@ mag_initialize (MagEventCB mag_event)
 	magnifier_create_region (magnifier, 2.0, 2.0, &roi , &roi);			 
 
 	magnifier_get_viewport (magnifier, 0, &rect);
-
+	
 	return TRUE;
 }
 
