@@ -25,6 +25,7 @@
 #include <libbonobo.h>
 
 static CORBA_Environment ev;
+MagRectangle zp_rect;
 
 void
 check_return_value (CORBA_Environment 	*env, 
@@ -157,6 +158,7 @@ magnifier_get_source (GNOME_Magnifier_Magnifier 	magnifier,
 	    {
 		if (source_rect)
 		{
+		    
 		    source_rect->left   = (long) rectangle->x1;
 		    source_rect->top    = (long) rectangle->y1;
 		    source_rect->width  = (long) rectangle->x2;
@@ -416,12 +418,51 @@ magnifier_set_crosswire_clip (GNOME_Magnifier_Magnifier 	magnifier,
 
 /*_____________________________ZOOMER PROPERTIES____________________________________*/
 
+static MagRectangle *
+mag_rect_clip_to_source (MagRectangle *roi)
+{    
+    static MagRectangle temp;
+    
+    if ((roi->width > zp_rect.left) && (roi->width < zp_rect.width))
+    {
+	if ((roi->top < zp_rect.height) && (roi->height > zp_rect.top))
+	{
+	    temp.width = zp_rect.left;
+	    temp.top = roi->top;
+	    temp.left = roi->left - (roi->width - zp_rect.left);
+	    temp.height = roi->height;
+	}
+	else
+	    return roi;    
+    }
+    else
+    if ((roi->left < zp_rect.width) && (roi->left > zp_rect.left))
+    {
+	if ((roi->top < zp_rect.height) && (roi->height > zp_rect.top))
+	{
+	    temp.width = (zp_rect.width - roi->left) + roi->width;
+	    temp.top = roi->top;
+	    temp.left = zp_rect.width;
+	    temp.height = roi->height;
+	}
+	else
+	    return roi;    
+    }
+    else 
+	return roi;
+    return &temp;
+}
+
+
 void
 magnifier_set_roi (GNOME_Magnifier_Magnifier 	magnifier,
 		   int 				zoom_region,
 		   MagRectangle 		*roi)
 {
     GNOME_Magnifier_ZoomRegionList 	*regions;
+    
+    
+    roi = mag_rect_clip_to_source (roi);
 
     if (magnifier)
     {
@@ -731,7 +772,7 @@ magnifier_resize_region (GNOME_Magnifier_Magnifier	magnifier,
 			 MagRectangle 			*viewport)
 {
     GNOME_Magnifier_ZoomRegionList	*regions;
-
+    
     if (magnifier)
     {
 	regions = GNOME_Magnifier_Magnifier_getZoomRegions (magnifier,
