@@ -1137,7 +1137,7 @@ src_presentation_get_info_from_sro (SRObject *obj,
 
 
 static gchar*
-src_presentation_present_sro_for_device_ (SRObject *obj,
+src_presentation_sro_get_pres_for_device_ (SRObject *obj,
 					  const gchar *device,
 					  SRCPresentationItem **chunk)
 {
@@ -1185,7 +1185,7 @@ src_presentation_present_sro_for_device_ (SRObject *obj,
 			      continue;
 			    
 			    tmp = add;
-			    tmp2 = src_presentation_present_sro_for_device_ (child, device, (SRCPresentationItem **)chunk[i]->data1);
+			    tmp2 = src_presentation_sro_get_pres_for_device_ (child, device, (SRCPresentationItem **)chunk[i]->data1);
 			    
 			    tmp3 = NULL;
 			    if (j != cnt - 1 && chunk[i]->data2)
@@ -1306,7 +1306,7 @@ src_presentation_present_sro_for_device_ (SRObject *obj,
 
 
 gchar*
-src_presentation_present_sro_for_magnifier (SRObject *obj, 
+src_presentation_sro_get_pres_for_magnifier (SRObject *obj, 
 					    const gchar *reason)
 {
     gchar *role;
@@ -1356,7 +1356,7 @@ src_presentation_present_sro_for_magnifier (SRObject *obj,
 
 
 gchar*
-src_presentation_present_sro_for_speech (SRObject *obj, 
+src_presentation_sro_get_pres_for_speech (SRObject *obj, 
 					 const gchar *reason)
 {
     SRCPresentationItem **presentation;
@@ -1400,7 +1400,7 @@ src_presentation_present_sro_for_speech (SRObject *obj,
 	}
 	else if (src_presentation_find_chunk_for_speech (role, reason, &presentation))
 	{
-	    presentation_ = src_presentation_present_sro_for_device_ (obj, device, presentation);
+	    presentation_ = src_presentation_sro_get_pres_for_device_ (obj, device, presentation);
 	}
 	SR_freeString (role);    
     }
@@ -1409,7 +1409,7 @@ src_presentation_present_sro_for_speech (SRObject *obj,
 }
 
 gchar*
-src_presentation_present_sro_for_braille (SRObject *obj, 
+src_presentation_sro_get_pres_for_braille (SRObject *obj, 
 					  const gchar *reason)
 {
     SRCPresentationItem  **presentation;
@@ -1423,7 +1423,7 @@ src_presentation_present_sro_for_braille (SRObject *obj,
     {
 	if (src_presentation_find_chunk_for_braille (role, reason, &presentation))
 	{
-	    presentation_ = src_presentation_present_sro_for_device_ (obj, device, presentation);
+	    presentation_ = src_presentation_sro_get_pres_for_device_ (obj, device, presentation);
 	}
 	SR_freeString (role);    
     }
@@ -1433,7 +1433,7 @@ src_presentation_present_sro_for_braille (SRObject *obj,
 
 
 gchar *
-src_presentation_present_sro_for_device (SRObject *obj, 
+src_presentation_sro_get_pres_for_device (SRObject *obj, 
 					 const gchar *reason, 
 					 const gchar *device)
 {
@@ -1442,11 +1442,11 @@ src_presentation_present_sro_for_device (SRObject *obj,
     sru_assert (obj && device && reason);
 
     if (strcmp (device, "magnifier") == 0)
-	presentation_ = src_presentation_present_sro_for_magnifier (obj, reason);
+	presentation_ = src_presentation_sro_get_pres_for_magnifier (obj, reason);
     else  if (strcmp (device, "speech") == 0)
-	presentation_ = src_presentation_present_sro_for_speech (obj, reason);
+	presentation_ = src_presentation_sro_get_pres_for_speech (obj, reason);
     else if (strcmp (device, "braille") == 0)
-	presentation_ = src_presentation_present_sro_for_braille (obj, reason);
+	presentation_ = src_presentation_sro_get_pres_for_braille (obj, reason);
     else
 	sru_assert_not_reached ();
 
